 void work()
 {
 if (x)
   {
   action(el, 1);
   return;
   }
 code();
 action(el, 1);
 }
